bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 28. Aventiure
___________________________________________________
| ### <Do> di Bvergonden chomen in Eceln lant ### do gevriesh ez von Berne der alte Hildebrant ### er sagtez sinem herren ez was im harte leit ### er bat in wol enpfahen di ritter chvene vnt gemeit ### Wolfhart der snelle hiez bringen div march ### do reit mit Dieteriche vil manich degen starch ### da er si grvezen wolde zv zin an daz velt ### da hetens vf gebvnden vil manich herlich gezelt
###### 1717 | ### Do si von Tronege Hagen verrest riten sach ### zv den sinen herren gezogenlich er sprach ### nv svlt ir snelle rechen von den sedeln stan ### vnd get <in> hin engegene di ivch da wellent enpfah
| ### Dort chvmt her ein gesinde daz ist mir wol bechant ### ez sint vil snelle degene von Amelvnge lant ### di fvert der von Berne di sint vil hohgemvt ### ir svlt iz niht versmahen swaz man iv dieneste getvt
###### 1719 | ### Do stvnden von den rossen daz was michel reht ### neben Dieteriche manich ritter vnd kneht ### si giengen zv den gesten da man di helde vant ### si grvoz [376b] ten minnechlichen di von Bvrgonden lant
###### 1720 | ### Do si der herre Dieterich gegen im chomen sach ### hie mveget ir gerne hoeren waz do der degen sprach ### zv den Vten chinden ir reise was im leit ### er wand ez wiste Rvedger daz erz in hete geseit
| ### Sit willechomen ir herren Gvnther vnd Giselher ### Gernot vnde Hagene sam si her Voelker ### vnt Danchwart der vil snelle ist iv daz niht bechant ### Criemhilt noh sere weinet den helt von Nibelvnge lant
###### 1722 | ### Si mach wol lange weinen sprach do Hagene ### er lit von manigem iare gar ce tode erslagene ### den kvenech von den Hivnen den sol si holden haben ### Sifrit chvmt niht widere er ist vor maniger zit begraben
###### 1723 | ### Di Sifrides wnden lazen wir nv sten ### sol leben div vrowe Crimhilt noch mag schade ergen ### so redet von Berne der herre Dieterich ### trost der Nibelvnge da vor behvete dv dich
| ### Wi sol ich mich behevten sprach der ### Ecel vns boten sande wes sol ich vragen mer ### daz wir zv zim solden riten her in daz lant ### ovch hat vns menigiv mære min swester Criemhilt gesant
###### 1725 | ### Ich chan iv wol geraten sprach aber Hagene ### ni bitet iv div mære baz ce sagene ### den herren Dieterichen vnt sine helde gvt ### daz si ivch laze wizen der vrovn Criemhilde mvt
###### 1726 | ### Do giengen svndersprachen di drie kvenge rich ### <Gventher> vnd Gernot vnd ovch her Dieterich ### nv sage vns von Berne vil edel ritter gvt ### wi dir si gewizen vmb der chveneginne mvt
| ### Do sprach der voget von Berne waz sol ich mere sagen ### ich hoer alle morgen weinen vnd klagen ### mit iamerlichen sitten daz Eceln wip ### dem richen got von himele des starchen Sifrides lip
###### 1728 | ### Ez ist et vnerwendet sprach der [377a] chvene man ### Volker der videlære daz wir vernomen han ### wir svln ce hove riten vnd svln lazen sehen ### waz vns vil snellen degenen da cen Hivnen mvege geshehen
###### 1729 | ### Di chvnen Bvrgonden hinze hove ritten ### si chomen herliche nach des landes sitten ### do wnderte da cen Hivnen vil manegen chvenen man ### vmb Hagen von Tronege wi der wære getan
| ### Dvrch daz man sagete mære des was im genvch ### daz er von Niderlande Sifriden slvch ### sterchest aller recken den Crimhilde man ### des wart michel vrage ce hove nach Hagene getan
###### 1731 | ### Der helt was wol gewahsen daz ist al war ### groz was er cen brvsten gemischet was sin har ### mit einer grisen varwe div bein warn im lanch ### vnd eislich sin gesihene er hete herlichen ganch
###### 1732 | ### Do hiez man herbergen di Bvergonden man ### Gvntheres ingesinde daz wart gesvndert dan ### daz riet div im vil hazes trvch ### da von man sit di knehte in der herberge slvch
| ### Danchwart Hagen brvder der was marshalch ### der kvnech im sin gesinde vlizechlich bevalch ### daz er ir vil wol pflege vnd in gæbe genvch ### der helt von Bvrgonden in allen gvten willen trvch
###### 1734 | ### Criemhilt div schone mit ir gesinde gie ### da si di Nibelvnge mit valschem mvt enpfie ### si chvste Giselhern vnd nam in bi der hant ### daz sah von Tronege Hagene den helm er vaste gebant
###### 1735 | ### Nach svs getanem grvze sprach do Hagene ### mvegen sich verdenchen snelle degene ### man grvzet svnderlingen di chvene vnd ir man ### wir haben niht gvter reise zv dirre hohgezit getan
| ### Si sprach sit willechomen swer ivch gerne siht ### dvrch iwer selbes frivntschaft so grveze ich iwer niht ### saget waz ir mir bringet von Wormez vber Rin ### dar vmb ir mir so groze soldet willechomen sin [377b]
###### 1737 | ### Het ich gewest div mære sprach do Hagene ### daz iv gabe solden bringen degene ### ich wære wol so riche het ich mich baz verdaht ### daz ich iv mine gabe her ce lande hete braht
###### 1738 | ### Nv svlt ir mich der mære mere wizen lan ### hort der Nibelvnge war <habt> ir den getan ### der was doh min eigen daz ist wol bechant ### den soldet ir mir fveren in daz Eceln lant
| ### Entriwen min vrov Criemhilt des ist vil manech tach ### daz ich hort der Nibelvnge nie nie gepflach ### den hiezn mine herren senchen in den Rin ### da mvz er wærliche vnz an daz ivngeste sin
###### 1740 | ### Do sprach div chvneginne ich hans ovch gedaht ### ir habt mirs noch vil wenich her ce lande braht ### swi er min eigen wære vnde ich sin wilen pflach ### des han ich alle zite vil manigen trvrigen tach
###### 1741 | ### Ia bringe ich iv den tivel sprach aber Hagene ### ich han an minem schilde so vil ce tragene ### vnd an der minen brvenne min helm der ist so lieht ### daz swert an miner hende des enbringe ich iv nieht
| ### Do sprach div chvneginne cen recken veber al ### man sol decheiniv waffen tragen in den sal ### ir helde ir svlt mirs vf geben ich wil si behalten lan ### entrivwen sprach do Hagene ez wirdet nimmer getan
###### 1743 | ### Iane ger ich niht der eren fvrsten wine milt ### daz ir cen herbergen trveget minen schilt ### vnde ander min geweffen ir sit ein chvenegin ### daz en lerte mich niht min vater ich wil selbe kamærære sin
###### 1744 | ### Owe miner leide sprach do vrov Criemhilt ### war vmbe wil <min> brvder vnd Hagen sinen schilt ### niht lazen behalten si sint gewarnot ### vnd wesse ich wær daz tæte der mvese chiesen den tot
| ### Des antwrte ir mit zorne der fverste Dieterich ### ich pin iz der hat gewarnet di edeln chvnege rich ### vnd Hagen den chvenen den Bvrgonden man ### nv zv valandinne dvne solt michs niht geniezzen lan
###### 1746 | ### Des schamte sich vil sere daz Eceln wip [378a] ### si vorhte bitterlichen den Dieteriches lip ### do gi si von im balde daz si nine sprach ### wan daz si swinde bliche an ir viande sah
###### 1747 | ### Behenden sich do viengen zwene degene ### daz eine was her Dieterich daz ander Hagene ### do sprahc gezogenliche der recke vil gemeit ### daz iwer chomen cen Hivnen daz ist mir wærliche leit
| ### Dvrch daz <div> chveneginne daz gesprochen hat ### do sprach von Tronege Hagene es wirt wol alles rat ### svs redeten mit ein ander di zwene chvene man ### daz der kvenech Ecel dar vmbe vragen began
###### 1749 | ### Div mære weste ich gerne sprach der kvenech rich ### wer der reche wære den dort her Dieterich ### so frivntlich enpfahet er treit vil hohen mvt ### swer sin vater wære er mach wol sin ein helt gvt
###### 1750 | ### Des antwrte dem chvenege ein Crimhilde man ### er ist geborn von Tronege sin vater hiez Aldrian ### swi blid er hie gebare er ist ein grimmer man ### ich laze ivch daz wol schowen daz ich gelogen nine han
| ### Wi sol ich daz erchennen daz er so grimmech ist ### dannoch er nien vesse vil manigen argen list ### den sit div chveneginne an ir magen begie ### daz si mit dem lebene deheinen von den Hivnen lie
###### 1752 | ### Wol erchande ich Aldrianen der was min man ### lob vnd michel <ere> er hi bi mir gewan ### ich machete in ce ritter vnd gap im min golt ### Helche div getriwe was im innechlichen holt
###### 1753 | ### Da von ich wol erchenne allererst wer <si> sint ### ez wrden mine gisel zwei wætlichiv chint ### er vnde von Spanye Walther di whsen hi ce man ### Hagen sande ich wider heim Walther mit Hiltegvnt entran
| ### Er gedahte langer mære div warn ê geschehen ### sinen frivnt von Tronege den het er reht ersehen ### der im in siner ivgende vil starchiv dienest bot ### sit frvmt er im in alter vil manigen lieben vrivnt <tot> [378b]

<<< Übersicht <<< vorige Seite nächste Seite >>>